.. _api_viewing_geo:

Viewing Geometry
================
.. autosummary::
    :toctree: generated/

    sasktran2.ViewingGeometry

Viewing Policies
----------------

.. autosummary::
    :toctree: generated/

    sasktran2.TangentAltitudeSolar
    sasktran2.GroundViewingSolar


Solar Geometry
--------------
.. autosummary::
    :toctree: generated/

    sasktran2.solar.SolarGeometryHandlerAstropy
    sasktran2.solar.SolarGeometryHandlerForced


Conversions
-----------
.. autosummary::
    :toctree: generated/

    sasktran2.viewinggeo.ecef_to_sasktran2_ray


Containers
----------
.. autosummary::
    :toctree: generated/

    sasktran2.viewinggeo.LimbVertical
